@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 13
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20230714
+#define __GLIBCXX__ 20230801
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1834,12 +1834,18 @@ namespace __gnu_cxx
 /* Define if fchmodat is available in <sys/stat.h>. */
 #define _GLIBCXX_USE_FCHMODAT 1
 
+/* Define if fseeko and ftello are available. */
+#define _GLIBCXX_USE_FSEEKO_FTELLO 1
+
 /* Defined if gettimeofday is available. */
 #define _GLIBCXX_USE_GETTIMEOFDAY 1
 
 /* Define if get_nprocs is available in <sys/sysinfo.h>. */
 #define _GLIBCXX_USE_GET_NPROCS 1
 
+/* Define if init_priority should be used for iostream initialization. */
+#define _GLIBCXX_USE_INIT_PRIORITY_ATTRIBUTE 1
+
 /* Define if LFS support is available. */
 #define _GLIBCXX_USE_LFS 1
 
